@@ -18,8 +18,12 @@
 ( cd opt/kde/share/doc/HTML/ru/karm ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kate ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kate ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kdat ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kdat ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kdvi ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kdvi ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kget ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kget ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kgpg ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kgpg ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kmag ; rm -rf common )
@@ -32,58 +36,120 @@
 ( cd opt/kde/share/doc/HTML/ru/kodo ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kolf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kolf ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kpat ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kpat ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kpdf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kpdf ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/korn ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/korn ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kppp ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kppp ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/krdc ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/krdc ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/krec ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/krec ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/krfb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/krfb ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kscd ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kscd ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/ksim ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/ksim ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/lisa ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/lisa ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kxkb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kxkb ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kalzium ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kalzium ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/katomic ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/katomic ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/ksysguard ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/ksysguard ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kbounce ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kbounce ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kdearch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kdearch ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kdelirc/kcmlirc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kdelirc/kcmlirc ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kdelirc/irkick ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kdelirc/irkick ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kbattleship ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kbattleship ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kaboodle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kaboodle ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/knewsticker ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/knewsticker ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kfloppy ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kfloppy ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/cervisia ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/cervisia ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/khexedit ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/khexedit ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kpercentage ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kpercentage ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kandy ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kandy ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcalc ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcalc ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kdesu ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kdesu ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcron ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcron ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kdict ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kdict ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kedit ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kfind ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kfind ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kjots ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kjots ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kmail ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kmail ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kmoon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kmoon ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/knode ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/knode ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kooka ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kooka ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/ksame ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/ksame ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/ksirc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/ksirc ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/ktnef ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/ktnef ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/ksysv ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/ksysv ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/ktron ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/ktron ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kuser ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kuser ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kview ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kview ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kwin4 ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kwin4 ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/lskat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/lskat ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/klipper ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/klipper ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kvoctrain ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kvoctrain ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kmousetool ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kmousetool ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/ksnapshot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/klinkstatus ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kompare ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kompare ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kontact ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kontact ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/konsole ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/konsole ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/konsolekalendar ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/konsolekalendar ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcachegrind ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kpackage ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kpackage ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/khelpcenter/faq ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/khelpcenter/quickstart ; rm -rf common )
@@ -96,18 +162,30 @@
 ( cd opt/kde/share/doc/HTML/ru/khelpcenter/userguide ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/khelpcenter/visualdict ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kshisen ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kshisen ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/ksirtet ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/ksirtet ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/konquest ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/konquest ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kspaceduel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kverbos ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kverbos ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kwallet ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kwallet ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kweather ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kweather ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kxsldbg ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kxsldbg ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
-( cd opt/kde/share/doc/HTML/ru/aktion ; rm -rf common )
-( cd opt/kde/share/doc/HTML/ru/aktion ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kwifimanager ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kwifimanager ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kbugbuster ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kmenuedit ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kioslave ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kioslave ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf fdl-license )
@@ -204,46 +282,134 @@
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/kdm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/smb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/spellchecking ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/bell ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/arts ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/arts ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/keys ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/keys ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/powerctrl ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kalarmd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/cookies ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/filetypes ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/filetypes ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/desktop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/desktop ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/cache ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/cache ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/clock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/email ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/email ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/fonts ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/fonts ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/icons ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/icons ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/khtml ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/khtml ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/filemanager ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/filemanager ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/mouse ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/panel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/panel ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/proxy ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/kmixcfg ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/lanbrowser ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/lanbrowser ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/passwords ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/panelappearance ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/panelappearance ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/ebrowsing ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/background ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/background ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmaccess ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmaccess ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/colors ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/colors ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/crypto ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/energy ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/energy ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmstyle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmstyle ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/netpref ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmlaunch ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmktalkd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmktalkd ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmcss ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/laptop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmnotify ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmsmserver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/screensaver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/screensaver ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/windowmanagement ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/windowmanagement ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kwindecoration ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kwindecoration ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmkonsole ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmkonsole ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/language ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/language ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/useragent ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/helpindex ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/helpindex ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmlowbatcrit ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmlowbatwarn ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmlowbatwarn ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/keyboard ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmtaskbar ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmfontinst ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/artsbuilder ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/artsbuilder ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kicker-applets ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kbabel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kbabel ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kamera ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kamera ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kdeprint ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kdeprint ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kasteroids ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kasteroids ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kbruch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kbruch ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/keduca ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/keduca ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kgamma ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kgamma ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
-( cd opt/kde/share/doc/HTML/ru/kdevelop ; rm -rf common )
-( cd opt/kde/share/doc/HTML/ru/kdevelop ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kmessedwords ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kicker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kicker ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/klatin ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/klatin ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/klines ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/klines ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kmines ; rm -rf common )
@@ -252,38 +418,74 @@
 ( cd opt/kde/share/doc/HTML/ru/kmouth ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kmplot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kmplot ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/knotes ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/knotes ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kpager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kpager ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kopete ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kopete ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kpoker ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kpoker ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kruler ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kruler ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/ktalkd ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/ktalkd ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/ksnake ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/ksnake ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kspell ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kspell ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kstars ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kstars ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/ktimer ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/ktimer ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/ktouch ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/ktouch ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kwrite ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kwrite ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/megami ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/megami ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kreversi ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kreversi ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/noatun ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/noatun ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/ksplashml ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/ksplashml ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kdebugdialog ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcharselect ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcharselect ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/quanta ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/quanta ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kolourpaint ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kolourpaint ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kde_app_devel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kde_app_devel ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kiconedit ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kiconedit ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/klettres ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/klettres ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kghostview ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kghostview ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/klickety ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/klickety ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kpovmodeler ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kleopatra ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kleopatra ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kjumpingcube ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kenolaba ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kenolaba ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kgpgcertmanager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kwatchgnupg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kwatchgnupg ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kworldclock ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/KRegExpEditor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/KRegExpEditor ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/ksokoban ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/ksokoban ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kteatime ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kteatime ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/dma ; rm -rf common )
@@ -300,6 +502,8 @@
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/devices ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/blockdevices ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/xserver ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/samba ; rm -rf common )
@@ -326,5 +530,9 @@
 ( cd opt/kde/share/doc/HTML/ru/umbrello ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/konqueror ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/konqueror ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kwordquiz ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kwordquiz ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/korganizer ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/korganizer ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/atlantik ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/atlantik ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
